/***********************
        IO.C -- Input/Ouput routines
************************/


#include "sys.h"                        /* system wide definitions */
#include "lex.h"                        /* lexical analyzer defs   */
#include "struct.h"                     /* spreadsheet structure   */
#include "io.h"                         /* I/O parameters          */

static unsigned int cell_width;

                        /* the following macro should print a value */
#define show_val_internal(v) printf("%*.*g", cell_width - SEP, SIGFIGS, v)

void show_val(v)
double v;
{
        show_val_internal(v);
}

void init_disp()
{
     cell_width = INIT_CELL_WIDTH;
}

/**
        show all the values on the spreadsheet
**/

void show_all(spread, max_row, max_col)
cell_ptr spread[][NUM_COL];
unsigned int max_row, max_col;
{
        static unsigned int i, j;
        static cell_ptr *c;

        for(i = 0; i<= max_row; i++)
        {
                c = spread[i];
                 for(j = 0; j <= max_col; j++, c++)
                 {
                       if(*c && (*c)->type == NUMBER)
                       {
                          move_curs(i, j);
                          show_val_internal((*c)->data.value);
                       }
                 }
        }
}


void show_cols(strt)
char strt;
{
        unsigned int i;

        for(i=0; i < NUM_COL; i++)
        {
                set_curs(-1, (strt - FIRST_COL));
                printf("%-*c", cell_width, strt);
                strt++;
        }
}


void show_rows(strt)
unsigned int strt;
{
        unsigned int i;

        for(i=0; i < NUM_ROW; i++)
        {
                scr_pos(strt + INIT_ROW - FIRST_ROW, INIT_COL - 2);
                printf("%-2d", strt);
                strt++;
        }
}


/**
        Show the contents of a cell
**/
void show_cell(curr, row, col)
cell_ptr curr;
unsigned int row, col;
{
        if(curr)
        {
                show_text(curr->text, row + FIRST_ROW, col + FIRST_COL);
        }
        else
        {
                show_text("", row + FIRST_ROW, col + FIRST_COL);
        }
        move_curs(row, col);
}

void show_label(s, row, col)
char *s;
{
        move_curs(row, col);

        s++;
        printf("%s", s);
}



#if DEBUG
#define LINE_LEN 8

void dump_instrs(code, last)
pointer code;
unsigned int last;
{
        extern char instrs[];

        unsigned int i;

        printf("\nCode starts at %x\n", code);
        printf("(instrs starts at %x)\n", instrs);

        for(i=0; i<last; i++)
        {
                if(i % LINE_LEN == 0) printf("\n");
                printf("%3x: %2x ", i, code[i] & 0x0ff);
        }
        printf("\n");
}
#endif
